==> kefu-sdk-1.1.9-sources.jar: com/hyphenate/helpdesk/model/ContentFactory.java <==
package com.hyphenate.helpdesk.model;


import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.List;

public class ContentFactory {
    public static VisitorInfo createVisitorInfo(JSONObject obj) {
        if (obj == null)
            return new VisitorInfo();
        else
            return new VisitorInfo(obj);
    }

    public static VisitorTrack createVisitorTrack(JSONObject obj) {
        if (obj == null)
            return new VisitorTrack();
        else
            return new VisitorTrack(obj);
    }

    public static RobotMenuInfo createRobotMenuInfo(JSONObject obj) {
        if (obj == null)
            return new RobotMenuInfo();
        else
            return new RobotMenuInfo(obj);
    }

    public static OrderInfo createOrderInfo(JSONObject obj) {
        if (obj == null)
            return new OrderInfo();
        else
            return new OrderInfo(obj);
    }

    public static AgentInfo createAgentInfo(JSONObject obj) {
        if (obj == null)
            return new AgentInfo();
        else
            return new AgentInfo(obj);
    }

    public static TransferIndication createTransferIndication(JSONObject obj) {
        if (obj == null)
            return new TransferIndication();
        else
            return new TransferIndication(obj);

    }

    static Event createEvent(JSONObject obj) {
        if (obj == null)
            return new Event();
        else
            return new Event(obj);

    }

    public static ControlMessage createControlMessage(JSONObject obj) {
        if (obj == null)
            return new ControlMessage();
        else
            return new ControlMessage(obj);

    }

    static ControlType createControlType(String value) {
        if (value == null)
            return new ControlType();
        else
            return new ControlType(value);

    }

    static ControlArguments createControlArguments(JSONObject obj) {
        if (obj == null)
            return new ControlArguments();
        else
            return new ControlArguments(obj);
    }

    public static QueueIdentityInfo createQueueIdentityInfo(String value) {
        if (value == null)
            return new QueueIdentityInfo();
        else
            return new QueueIdentityInfo(value);
    }

    public static AgentIdentityInfo createAgentIdentityInfo(String value) {
        if (value == null)
            return new AgentIdentityInfo();
        else
            return new AgentIdentityInfo(value);
    }

    static ToCustomServiceInfo createToCustomeServiceInfo(JSONObject obj) {
        if (obj == null)
            return new ToCustomServiceInfo();
        else
            return new ToCustomServiceInfo(obj);

    }

    public static RobotMenuIdInfo createRobotMenuIdInfo(JSONObject obj){
        if (obj == null){
            return new RobotMenuIdInfo();
        }else{
            return new RobotMenuIdInfo(obj);
        }

    }

    static EvaluationInfo createEvaluationInfo(JSONObject obj){
        if (obj == null){
            return new EvaluationInfo();
        }else{
            return new EvaluationInfo(obj);
        }
    }

    static ArticlesInfo createArticlesInfo(JSONObject obj) {
        if (obj == null) {
            return new ArticlesInfo();
        } else {
            return new ArticlesInfo(obj);
        }
    }

    static FormInfo createFormInfo(JSONObject content) {
        if (content == null) {
            return new FormInfo();
        } else {
            return new FormInfo(content);
        }
    }

    public static ControlMessage createEvaluationResponse(EvaluationInfo evaluationInfo, String detail, int summary, int degreeId, List<EvaluationInfo.TagInfo> appraiseTags){
        ControlMessage controlMessage = new ControlMessage();
        controlMessage.setControlType(ControlMessage.TYPE_EVAL_RESPONSE);
        controlMessage.setArgumentsValue("detail", detail);
        controlMessage.setSummary(summary);
        if (degreeId > 0){
            controlMessage.setArgumentsValue("evaluationDegreeId", degreeId);
        }
        if (evaluationInfo != null) {
            controlMessage.setArgumentsValue("inviteId", evaluationInfo.getInviteId());
            controlMessage.setArgumentsValue("serviceSessionId", evaluationInfo.getSessionId());
        }
        if (appraiseTags != null && !appraiseTags.isEmpty()){
            JSONArray jsonArray = new JSONArray();
            for (EvaluationInfo.TagInfo info : appraiseTags){
                JSONObject jsonItem = new JSONObject();
                try {
                    jsonItem.put("id", info.getId());
                    jsonItem.put("name", info.getName());
                    jsonArray.put(jsonItem);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
            controlMessage.setArgumentsValue("appraiseTags", jsonArray);
        }
        return controlMessage;
    }


}

==> kefu-sdk-1.3.2.9-sources.jar: com/hyphenate/helpdesk/model/ContentFactory.java <==
package com.hyphenate.helpdesk.model;


import android.text.TextUtils;

import com.hyphenate.helpdesk.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.List;

public class ContentFactory {
    public static VisitorInfo createVisitorInfo(JSONObject obj) {
        if (obj == null)
            return new VisitorInfo();
        else
            return new VisitorInfo(obj);
    }

    public static VisitorTrack createVisitorTrack(JSONObject obj) {
        if (obj == null)
            return new VisitorTrack();
        else
            return new VisitorTrack(obj);
    }

    public static RobotMenuInfo createRobotMenuInfo(JSONObject obj) {
        if (obj == null)
            return new RobotMenuInfo();
        else
            return new RobotMenuInfo(obj);
    }

    public static TransferGuideMenuInfo createTransferGuideMenuInfo(JSONObject obj) {
        if (obj == null)
            return new TransferGuideMenuInfo();
        else
            return new TransferGuideMenuInfo(obj);
    }

    public static OrderInfo createOrderInfo(JSONObject obj) {
        if (obj == null)
            return new OrderInfo();
        else
            return new OrderInfo(obj);
    }

    public static AgentInfo createAgentInfo(JSONObject obj) {
        if (obj == null)
            return new AgentInfo();
        else
            return new AgentInfo(obj);
    }

    public static TransferIndication createTransferIndication(JSONObject obj) {
        if (obj == null)
            return new TransferIndication();
        else
            return new TransferIndication(obj);

    }

    static Event createEvent(JSONObject obj) {
        if (obj == null)
            return new Event();
        else
            return new Event(obj);

    }

    public static ControlMessage createControlMessage(JSONObject obj) {
        if (obj == null)
            return new ControlMessage();
        else
            return new ControlMessage(obj);

    }

    static ControlType createControlType(String value) {
        if (value == null)
            return new ControlType();
        else
            return new ControlType(value);

    }

    static ControlArguments createControlArguments(JSONObject obj) {
        if (obj == null)
            return new ControlArguments();
        else
            return new ControlArguments(obj);
    }

    public static QueueIdentityInfo createQueueIdentityInfo(String value) {
        if (value == null)
            return new QueueIdentityInfo();
        else
            return new QueueIdentityInfo(value);
    }

    public static AgentIdentityInfo createAgentIdentityInfo(String value) {
        if (value == null)
            return new AgentIdentityInfo();
        else
            return new AgentIdentityInfo(value);
    }

    static ToCustomServiceInfo createToCustomeServiceInfo(JSONObject obj) {
        if (obj == null)
            return new ToCustomServiceInfo();
        else
            return new ToCustomServiceInfo(obj);

    }

    public static RobotMenuIdInfo createRobotMenuIdInfo(JSONObject obj){
        if (obj == null){
            return new RobotMenuIdInfo();
        }else{
            return new RobotMenuIdInfo(obj);
        }

    }

    public static TransferGuideQueneInfo createTransferGuideQueueInfo(JSONObject obj) {
        if (obj == null) {
            return new TransferGuideQueneInfo();
        }else  {
            return new TransferGuideQueneInfo(obj);
        }
    }

    static EvaluationInfo createEvaluationInfo(JSONObject obj){
        if (obj == null){
            return new EvaluationInfo();
        }else{
            return new EvaluationInfo(obj);
        }
    }

    static ArticlesInfo createArticlesInfo(JSONObject obj) {
        if (obj == null) {
            return new ArticlesInfo();
        } else {
            return new ArticlesInfo(obj);
        }
    }

    static FormInfo createFormInfo(JSONObject content) {
        if (content == null) {
            return new FormInfo();
        } else {
            return new FormInfo(content);
        }
    }

    public static ControlMessage createEvaluationResponse(EvaluationInfo evaluationInfo, String detail, int summary, int degreeId, List<EvaluationInfo.TagInfo> appraiseTags){
        ControlMessage controlMessage = new ControlMessage();
        controlMessage.setControlType(ControlMessage.TYPE_EVAL_RESPONSE);
        controlMessage.setArgumentsValue("detail", detail);
        controlMessage.setSummary(summary);
        if (degreeId > 0){
            controlMessage.setArgumentsValue("evaluationDegreeId", degreeId);
        }
        if (evaluationInfo != null) {
            controlMessage.setArgumentsValue("inviteId", evaluationInfo.getInviteId());
            controlMessage.setArgumentsValue("serviceSessionId", evaluationInfo.getSessionId());
        }
        if (appraiseTags != null && !appraiseTags.isEmpty()){
            JSONArray jsonArray = new JSONArray();
            for (EvaluationInfo.TagInfo info : appraiseTags){
                JSONObject jsonItem = new JSONObject();
                try {
                    jsonItem.put("id", info.getId());
                    jsonItem.put("name", info.getName());
                    jsonArray.put(jsonItem);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
            controlMessage.setArgumentsValue("appraiseTags", jsonArray);
        }


        if (evaluationInfo != null){
            List<EvaluationInfo.ResolutionParam> resolutionParams = evaluationInfo.getResolutionParams();
            if ( resolutionParams != null && !resolutionParams.isEmpty()){
                JSONArray jsonArray = new JSONArray();

                for (EvaluationInfo.ResolutionParam info : resolutionParams){
                    JSONObject jsonItem = new JSONObject();
                    try {
                        jsonItem.put("id", info.getId());
                        jsonItem.put("name", info.getName());
                        jsonItem.put("score", info.getScore());

                        JSONArray resolutionParamTags = info.getResolutionParamTags();
                        if (resolutionParamTags != null){
                            jsonItem.put("resolutionParamTags", resolutionParamTags);
                        }

                        jsonArray.put(jsonItem);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }

                controlMessage.setArgumentsValue("resolutionParam", jsonArray);
                // evaluateWay 评价方式：由前端传入，visitor访客主动评价，agent坐席邀请，system强制邀请访客点击关闭窗口或会话结束
                if (!TextUtils.isEmpty(evaluationInfo.getEvaluateWay())){
                    controlMessage.setArgumentsValue("evaluateWay",evaluationInfo.getEvaluateWay());
                }
            }
        }

        return controlMessage;
    }


}
